@@ -21,7 +21,7 @@
 //!
 //! Add the following to the `[dependencies]` section of your Cargo.toml:
 //! ```toml
-//! solana-security-txt = "1.0.0"
+//! solana-security-txt = "1.0.1"
 //! ```
 //!
 //! To install the querying tool, execute
@@ -131,9 +131,9 @@
 //! #[macro_export]
 //! macro_rules! security_txt {
 //!     ($($name:ident: $value:expr),*) => {
+//!         #[cfg_attr(target_arch = "bpf", link_section = ".security.txt")]
 //!         #[allow(dead_code)]
 //!         #[no_mangle]
-//!         #[link_section = ".security.txt"]
 //!         pub static security_txt: &str = concat! {
 //!             "=======BEGIN SECURITY.TXT V1=======\0",
 //!             $(stringify!($name), "\0", $value, "\0",)*
@@ -183,9 +183,9 @@ pub const SECURITY_TXT_END: &str = "=======END SECURITY.TXT V1=======\0";
 #[macro_export]
 macro_rules! security_txt {
     ($($name:ident: $value:expr),*) => {
+        #[cfg_attr(target_arch = "bpf", link_section = ".security.txt")]
         #[allow(dead_code)]
         #[no_mangle]
-        #[link_section = ".security.txt"]
         pub static security_txt: &str = concat! {
             "=======BEGIN SECURITY.TXT V1=======\0",
             $(stringify!($name), "\0", $value, "\0",)*
